@@ -235,10 +235,13 @@ scoreboard players reset #count furnace_nbt_recipes.data
 	furnace_nbt_used: bool = False
 	furnace_nbt_vanilla_items: set[str] = set()
 	items: list[tuple[str, dict]] = list(config['database'].items())
+	any_recipe: bool = False
 	for item, data in items:
 		crafts: list[dict] = list(data.get(RESULT_OF_CRAFTING, []))
 		crafts += list(data.get(USED_FOR_CRAFTING, []))
 		for recipe in crafts:
+			if recipe["type"] in ["crafting_shapeless", "crafting_shaped"]:
+				any_recipe = True
 
 			# Transform ingr to a list of dicts
 			ingr: list[dict] = recipe.get("ingredients")
@@ -259,11 +262,12 @@ scoreboard players reset #count furnace_nbt_recipes.data
 				if not official_lib_used("furnace_nbt_recipes"):
 					debug(f"Found a furnace recipe using custom item in ingredient, adding 'furnace_nbt_recipes' dependency")
 	
-	# If smithed crafter is used, link the functions
-	shapeless_func_tag: str = f"{config['build_datapack']}/data/smithed.crafter/tags/function/event/shapeless_recipes.json"
-	shaped_func_tag: str = f"{config['build_datapack']}/data/smithed.crafter/tags/function/event/recipes.json"
-	write_to_file(shapeless_func_tag, super_json_dump({"values": [f"{config['namespace']}:calls/smithed_crafter/shapeless_recipes"]}))
-	write_to_file(shaped_func_tag, super_json_dump({"values": [f"{config['namespace']}:calls/smithed_crafter/shaped_recipes"]}))
+	# If there is any shaped or shapeless recipe, link the functions
+	if any_recipe:
+		shapeless_func_tag: str = f"{config['build_datapack']}/data/smithed.crafter/tags/function/event/shapeless_recipes.json"
+		shaped_func_tag: str = f"{config['build_datapack']}/data/smithed.crafter/tags/function/event/recipes.json"
+		write_to_file(shapeless_func_tag, super_json_dump({"values": [f"{config['namespace']}:calls/smithed_crafter/shapeless_recipes"]}))
+		write_to_file(shaped_func_tag, super_json_dump({"values": [f"{config['namespace']}:calls/smithed_crafter/shaped_recipes"]}))
 
 	# Generate recipes with vanilla input (no components)
 	vanilla_generated_recipes = []
